@@ -83,8 +83,7 @@ class PeUser(BaseModel):
             next_birthday = next_birthday.replace(year=from_date.year + 1)
         return next_birthday
 
-    @property
-    def years_next_birthday(self, from_date=date.today()) -> int:
+    def years_next_birthday(self, from_date: date = date.today()) -> int:
         return self.next_birthday().year - datetime.strptime(self.contract.ssn.split("-")[0], "%Y%m%d").year
 
     @property
